#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


# This file is a part of VHFFS4 software, a hosting platform suite
# Please respect the licence of this file and whole program

# Author : soda < dieu at gunnm dot org >

#This module helps you to manage a simple maildomain
#for all hosted people

#Be careful, you have to defined in your config:
# <services>
#    ....
#    ....
#    <mailuser>
#       activate = [yes|no]
#       domain = domain_to_share_with_hosted
#       user = vhffs_user_you_own_the_domain
#    </mailuser>
# </services>

# This module wrap user on the specified user
# and commit changes on the domain

package Vhffs::Services::MailUser;

use base qw(Vhffs::Object);
use strict;
use DBI;
use Vhffs::User;


# Create a new instance of the current class
sub init
{
	my $class = shift;
	my $vhffs = shift;
	my $user = shift;

	my $this = {};

	# Instance it as a main object to have links with the database
	$this = $class->SUPER::new( $vhffs , 1 , '401' );	

	my $config = $vhffs->get_config->get_service( "mailuser");
	return -1 if( ! defined $config );
	return -1 if( ( ! defined $config->{activate} ) || ( $config->{activate} ne "yes" ) );

	if( $user->fetch < 0 )
	{
		return -1;
	}
	else
	{
		$this->{part} = $user->get_username;
	}

	if( defined $config->{domain} )
	{
		$this->{domain} = $config->{domain};
	}
	else
	{
		return -2;
	}

	if( defined $config->{user} )
	{
		my $wuser = new Vhffs::User( $vhffs , $config->{user} , '401' );
		if( $wuser->fetch )
		{
			$this->{wuser} = $wuser;
		}
		else
		{
			return -4;
		}
	}
	else
	{	
		return -3;
	}

	my $object = new Vhffs::Services::Mail( $vhffs, $this->{domain} , $this->{wuser} , undef );

	if( $object->fetch < 0 )
	{
		return -5;
	}
	else
	{
		$this->{object} = $object;
	}


    bless( $this , $class );

	return $this;
}

sub available
{
	my $self = shift;
	my $config = $self->{main}->get_config->get_service( "mailuser");
	my $user = new Vhffs::User( $self->{main} , $self->{part} , '401' );	
	return 0 if( $user->fetch < 0 );
	return 1 if( ( ! defined $config->{groupneeded} ) || ( $config->{groupneeded} ne "yes" ) || ( $user->have_activegroups > 0 ) );
	return 0;
}

sub exists
{
	my $self = shift;
	return $self->{object}->exists( $self->{part} );
}

sub exists_forward
{
	my $self = shift;
	return $self->{object}->exists_forward( $self->{part} );
}


sub exists_box
{
	my $self = shift;
	return $self->{object}->exists_box( $self->{part} );
}

sub use_nospam
{
	my $self = shift;
	return $self->{object}->use_nospam( $self->{part} );
}

sub use_novirus
{
	my $self = shift;
	return $self->{object}->use_novirus( $self->{part} );
}

sub change_spam_status
{
	my $self = shift;
	$self->{object}->change_spam_status( $self->{part} );
	return -2 if( $self->{object}->commit < 0 );
	return 1;
}

sub change_virus_status
{
	my $self = shift;
	$self->{object}->change_virus_status( $self->{part} );
	return -2 if( $self->{object}->commit < 0 );
	return 1;
}


sub addforward
{
	my $self = shift;
	my $remote = shift;
	
	if( $self->exists_box == 1 )
	{
		$self->{object}->delbox( $self->{part} );
		$self->{object}->fetch;
	}
	
	return -1 if ( $self->{object}->addforward( $self->{part} , $remote ) < 0);
	return -2 if( $self->{object}->commit < 0 );
}

sub delforward
{
	my $self = shift;
    $self->{object}->delforward( $self->{part} );
}

sub delbox
{
	my $self = shift;
    $self->{object}->delbox( $self->{part} );
}

sub addbox
{
	my $self = shift;
	my $password = shift;


	if( $self->exists_forward == 1 )
	{
		$self->{object}->delforward( $self->{part} );
		$self->{object}->fetch;
	}

	return -1 if( $self->{object}->addbox( $self->{part} , $password ) < 0);
	return -2 if( $self->{object}->commit < 0 );
}





1;
