#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


# This file is a part of VHFFS4 platofmrm
# Please respect the licence

# Author: soda < dieu at gunnm dot org>


package Vhffs::Services::Postgres;

use base qw(Vhffs::Object);
use strict;
use DBI;



sub new
{
    my $main;
    my $dbname;
    my $this;
    my $self;
    my $class;
	my $user;
	my $group;

    #( $class , $main , $dbname , $user ) = @_;

	$class = shift;
	$main = shift;
	$dbname = shift;
	$user = shift;
	$group = shift;

    $this = {};
	
#    return undef if( $dbname =~ /^[\w\d\_\-]+$/ );

    return undef if( ! ( $dbname =~ /^[a-z0-9][a-z0-9\_]+[a-z0-9]$/ ) );
    return undef if( length( $dbname ) > 32 );

    $this = $class->SUPER::new( $main , 1 , '401' );

    $this->{'dbname'} = $dbname if ( defined $dbname );
    $this->{'dbuser'} = "";
    $this->{'user'} = $user if ( defined $user );
    $this->{'group'} = $group if ( defined $group );
    
	bless( $this , $class );

	return $this;
}

sub delete
{
    my $self = shift;

    my $query = "DELETE FROM vhffs_pgsql WHERE object_id='".$self->{'object_id'}."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

    return -2 if( $self->SUPER::delete < 0 );
    return 1;
}


sub create
{
	my $self = shift;

	return -1 if( $self->{'user'}->fetch < 0 );
	return -1 if ( $self->{'group'}->fetch < 0 );
	$self->{'owner_gid'} = $self->{'group'}->get_gid;
	$self->{'owner_uid'} = $self->{'user'}->get_uid;


	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_pgsql WHERE dbname='" . $self->{'dbname'} . "'");
    my $rows = $request->execute;
    return -1 if ( $rows != 0 );

    my $oid = $self->SUPER::create();
    return -1 if ( $oid lt 0 );


	$self->{'object_id'} = $oid;

	return -2 if ( ( ! defined $self->{'dbuser'} ) || ( ! defined $self->{'dbpass'} ) );

	#Get the mac httpd_id and compute the new httpd_id
    my $pgsql_id = 1;
    my $resultuid = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(pgsql_id) FROM vhffs_pgsql");
    $pgsql_id = $resultuid->[0][0] if ( defined $resultuid->[0][0] );
    $pgsql_id++;


	#Finally, create the object
	my $query = "INSERT INTO vhffs_pgsql VALUES( '".$pgsql_id."' , '".$self->{'dbname'} . "', '".$self->{'dbuser'}."' , '".$self->{'dbpass'}."' , '".$self->{'owner_uid'}."', '".$self->{'owner_gid'}."' , '$oid'  )";
	$request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute or return -2;

	return $pgsql_id;
}


#Get all data about this httpd object in the databse
sub fetch
{
	my $self = shift;

	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_pgsql where dbname='".$self->{'dbname'}."'") or return -1;
    my $rows = $request->execute();

	return -1 if( $rows != 1 );

    my $result = $request->fetchrow_hashref();


	foreach ( keys %{$result} )
	{
		$self->{$_} = $result->{$_}
	}

	$self->SUPER::fetch;
}



sub commit
{
	my $self = shift;	

	my $query = "UPDATE vhffs_pgsql SET owner_uid='".$self->{'owner_uid'}."', dbuser= '".$self->{'dbuser'}."', dbpass='".$self->{'dbpass'}."' WHERE dbname='".$self->{'dbname'}."'";
	my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute;


	$self->SUPER::commit;
}

sub get_ownergid
{
	my $self = shift;
	return $self->{'owner_gid'};
}


sub get_owneruid
{
	my $self = shift;
	return $self->{'owner_uid'};
}




sub get_dbusername
{
	my $self = shift;
	return $self->{'dbuser'};
}

sub get_dbname
{
	my $self = shift;
	return $self->{'dbname'};
}


sub get_title
{
	my $self = shift;
	return $self->{'dbname'};
}

sub get_dbpassword
{
	my $self = shift;
	return $self->{'dbpass'};
}



sub set_dbusername
{
	my ($self , $value) = @_;	

	return 1 if( $value eq $self->{'dbuser'});

	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_pgsql where dbuser='".$value."'") or return -1;
    my $rows = $request->execute();

	return -1 if( $rows >= 1 );
	
	$self->{'dbuser'} = $value;
	return 1;
}

sub set_dbpassword
{
	my $self = shift;
	my $value = shift;
	return -1 if( ! ( $value =~ /^[a-zA-Z0-9]+$/ ) );
	$self->{'dbpass'} = $value;
	return 1;
}

sub set_group
{
	my( $self , $group ) = @_;
	$self->{'group'} = $group;
}

sub set_user
{
	my( $self , $user ) = @_;
	$self->{'user'} = $user;
}


sub blank_password
{   
    my $self = shift;
    
    my $request = $self->{'db'}->{'DB_READ'}->prepare("UPDATE vhffs_pgsql SET dbpass='blanked' WHERE dbname='".$self->get_dbname."'") or return -1;
    $request->execute();
    return 1;
}

sub getall
{   
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $group = shift;

    my $query;
    my $request;

    my @objs;
    my $result;
    my $tmp;

    $query = "SELECT dbname FROM vhffs_pgsql p, vhffs_object o WHERE o.object_id=p.object_id";
	$query .= " AND o.state='".$state."'" if( defined $state );
	$query .= " AND p.dbname LIKE '%".$name."%'" if( defined $name );
	$query .= " AND p.owner_gid='".$group->get_gid."'" if( defined $group );

    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows <= 0);
    $result = $request->fetchall_hashref('dbname');
    foreach( keys %{$result} )
    {
            $tmp = new Vhffs::Services::Postgres( $vhffs , $_ );
            if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
            {
                    push @objs , $tmp;
            }
    }
    return \@objs;
}


1;
