#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Stats;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs          = $panel->{'vhffs'};
my $session        = $panel->{'session'};
my $maintemplate   = $panel->{'template'};
my $user           = $panel->{'user'};
my $group          = $panel->{'group'};
my $projectname    = $session->param("project");
my $cgi            = $panel->{'cgi'};
my $username       = $cgi->param("USERNAME");


my $template;
my $object;
my $message;
my $mail;
my $firstname;
my $lastname;
my $city;
my $shell;
my $gpg_key;
my $zipcode;
my $status;
my $admin;
my $passwd;
my $country;
my $address;
my $templatedir = $vhffs->get_config->get_templatedir;
$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );

if( $user->is_admin != 1 )
{
    $message = gettext( "You are not allowed to see it");
    $template->param( MESSAGE => $message );
}
elsif( ! defined $username )
{
    #Here, this is a directly call to the script, username is not defined
    $message = gettext( "CGI ERROR !" );
    $template->param( MESSAGE => $message );
}
elsif( ( ! defined ( $object = new Vhffs::User( $vhffs , $username , '401' ) ) ) || ( $object->fetch < 0 ) )
{
    $message = gettext( "Cannot fetch object" );
    $template->param( MESSAGE => $message );
}
else
{

	$firstname = $cgi->param( "FIRSTNAME");
	$lastname  = $cgi->param( "LASTNAME" );
	$gpg_key   = $cgi->param( "GPG"      );
	$shell     = $cgi->param( "SHELL"    );
	$zipcode   = $cgi->param( "ZIPCODE"  );
	$city      = $cgi->param( "CITY"     );
	$country   = $cgi->param( "COUNTRY"  );
	$address   = $cgi->param( "ADDRESS"  );
	$status    = $cgi->param( "STATUS"   );
	$admin     = $cgi->param( "ADMIN"    );
	$mail      = $cgi->param( "USERMEL"     );
	$passwd    = $cgi->param( "PASSWORD" );
	
	$object->set_status   ( $status    );
	$object->set_admin    ( $admin     );
	$object->set_firstname( $firstname )      if( defined $firstname );
	$object->set_lastname ( $lastname  )      if( defined $lastname  );
	$object->set_gpgkey   ( $gpg_key   )      if( defined $gpg_key   );
	$object->set_shell    ( $shell     )      if( defined $shell     );
	$object->set_zipcode  ( $zipcode   )      if( defined $zipcode   );
	$object->set_country  ( $country   )      if( defined $country   );
	$object->set_address  ( $address   )      if( defined $address   );
	$object->set_city     ( $city      )      if( defined $city      );
	$object->set_mail     ( $mail      )      if( defined $mail      );
	$object->set_password ( $passwd    )      if( ( defined $passwd ) &&( length( $passwd ) > 1 ) );


	if( $object->commit < 0 )
	{
		$message = gettext("An error occured while updating");
	}
	else
	{
		$message = gettext("Modifications successfully applied");
	}

	$template->param( MESSAGE => $message );	

}

set_refresh_url Vhffs::Panel::Main($panel, "/admin/user/list.pl", 0);
display Vhffs::Panel::Main($panel, $template->output);
