#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $projectname = $session->param("project");

my $templatedir = $vhffs->get_config->get_templatedir;
my $template;
my $subtemplate;
my $message;


my $group = new Vhffs::Group( $vhffs , $projectname , '401' );

if( ( ! defined $group ) || ( $group->fetch < 0 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$template->param( MESSAGE => gettext( "Error. This group doesn't exists") );
}
elsif( $group->get_status != Vhffs::Constants::ACTIVATED )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$template->param( MESSAGE => gettext( "This object is not functional yet. Please wait creation or moderation.") );
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $group , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/group/prefs.tmpl" );


	$template->param( TEXT_TITLE => gettext("Project Preferences") );
$template->param( TEXT_QUOTA => gettext("If you want more disk space for your project, you must fill a form in the bug report section, in the menu. Don't forget to mention the name of the group.") );
	$template->param( TEXT_PROJECTNAME => $projectname );
	$template->param( TEXT_OWNER => gettext("Project Owner") );
	$template->param( VALUE_OWNER => $group->get_owner_username );
	$template->param( TEXT_DESCRIPTION => gettext("Project Description") );
	$template->param( VALUE_DESCRIPTION => $group->get_description);
	$template->param( VALUE_OID => $group->get_oid);
	$template->param( TEXT_MODIFY => gettext("Modify") );
	$template->param( TEXT_DELETE_PROJECT => gettext("Delete this project") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_PROJECT => gettext("Are you SURE you want DELETE this project ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );
	
	$template->param( TEXT_USERNAME => gettext("Username") );
	$template->param( TEXT_JOIN_GROUP => gettext("Add a user in this group") );
	$template->param( TEXT_SEND => gettext("Add this user !") );

	$template->param( SEND_AVATAR => gettext("Send logo") );
	$template->param( TEXT_AVATAR => gettext("Send logo") );
	$template->param( EXPLAIN_AVATAR => gettext("The avatar is an image to describe the group") );
	$template->param( CURRENT_AVATAR => gettext("Current avatar") );

	
	my $output = "";
	my $users = Vhffs::Panel::Group::getall_users_per_group( $vhffs , $group->get_groupname );
	
	foreach ( keys %{$users} )
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/group/each_user.tmpl" );
		$subtemplate->param( VALUE_GROUPNAME => $group->get_groupname );
		$subtemplate->param( TEXT_SUBMIT => gettext("Remove this user from this group" ) );
		$subtemplate->param( USERNAME => $_ );
		$output .= $subtemplate->output;
	}
	
	$template->param( SUBTITLE_USERS => gettext( "All users in this group" ) );
	$template->param( USERS => $output );
}

display Vhffs::Panel::Main($panel, $template->output);
