#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;
use Vhffs::Panel::Mailinglist;
use Vhffs::Services::Mailing;

my $panel = new Vhffs::Panel::Main;
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $groupname = $panel->{'groupname'};
my $cgi = $panel->{'cgi'};
my $message;

my $domain = $cgi->param("DOMAIN");
my $lpart = $cgi->param("LOCAL_PART");

my $description = $cgi->param("USAGE");


my $list;

my $templatedir = $vhffs->get_config->get_templatedir;
my $default_domain;
my $domains         = Vhffs::Panel::Mail::getall_mail_per_group( $group , $vhffs , Vhffs::Constants::ACTIVATED );
my $valid = 0;
if( defined $vhffs->get_config->get_service("mailing")->{'default_domain'} )
{
    $default_domain = $vhffs->get_config->get_service("mailing")->{'default_domain'};
}
else
{
    $default_domain = undef;
}

$valid = 1 if( $default_domain eq $domain );

foreach( sort ( keys %{$domains} ) )
{
    $valid = 1 if( $_ eq $domain );
}


if( ( ! defined $description ) || ( ! defined $domain ) || ( ! defined $lpart ) )
{
	$message = gettext("CGI Error");
}
elsif( $valid == 0 )
{
    $message = gettext("You don't own this domain");
}
else
{
	my $retour;
	$retour = Vhffs::Panel::Mailinglist::create_list( $vhffs , $lpart , $domain , $user , $group );

	if( $retour > 0 )
	{
		$message = gettext("Mailing-list successfully created !");

		$list = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain );
		$message = gettext("An error occured while fetching information about this mailing list") if( $list->fetch < 0 );
		$list->set_description( $description );
		$message = gettext("An error occured while applying changes") if ( $list->commit < 0 );
	}
	elsif( $retour == -1 )
	{
		$message = gettext("An error occured while creating the list");
	}
	elsif( $retour == -2 )
	{
		$message = gettext("An error occured while adding yourself to the ACL");
	}
	elsif( $retour == -3 )
	{
		$message = gettext("An error occured while adding an ACL for the group");
	}
	else
	{
		$message = gettext("Error while creating list (unknow problem)");
	}


#	$list->set_description( $description );
#	$list->commit;
}


my $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
$template->param( MESSAGE => $message );

set_refresh_url Vhffs::Panel::Main($panel, "/panel.pl?project=$groupname", 0);
display Vhffs::Panel::Main($panel, $template->output);
